@@ -116,15 +116,28 @@ class Url2Html(object):
             return ''
         title = self.replace_name(title)
 
-        account_name = self.article_info(html)[0]
-        date = self.timestamp2date(self.get_timestamp(html))
-        if not os.path.isdir(account_name):
-            os.mkdir(account_name)
+        try:
+            account_name = self.article_info(html)[0]
+        except:
+            account_name = '未分类'
+        try:
+            date = self.timestamp2date(self.get_timestamp(html))
+        except:
+            date = ''
+
+        try:
+            if not os.path.isdir(account_name):
+                os.mkdir(account_name)
+        except:
+            account_name = '未分类'
+            if not os.path.isdir(account_name):
+                os.mkdir(account_name)
+
         title = os.path.join(account_name,
                              '[{}]-{}-{}'.format(account_name, date, title))
         return title
 
-    def run(self, url, title=None, text=False, img=True, img_path=None):
+    def run(self, url, title=None, text=False, img=True, img_path=None, source=False):
         """
         启动函数
         url: 微信文章链接
@@ -132,6 +145,7 @@ class Url2Html(object):
         text: 只保存文章文本内容
         img: 是否需要下载图片
         img_path: 下载图片的路径。如果img==True, 那么img_path不能为None
+        source: 是否返回html源码,返回源码则不保存
         """
         if img:
             if img_path != None:
@@ -151,9 +165,12 @@ class Url2Html(object):
         if text:
             html_img = html
 
-        with open('{}.html'.format(title), 'w', encoding='utf-8') as f:
-            f.write(html_img)
 
+        if source:
+            return html_img
+        else:
+            with open('{}.html'.format(title), 'w', encoding='utf-8') as f:
+                f.write(html_img)
         return '{} success!'.format(url)
 
 
