@@ -3,6 +3,8 @@
 from .ArticlesUrls import ArticlesUrls
 from .ArticlesInfo import ArticlesInfo
 from .ArticlesAPI import ArticlesAPI
+from .Url2Html import Url2Html
+from .nickname2biz import nickname2biz
 from .GetUrls import PCUrls, MobileUrls
 
 try:
@@ -10,4 +12,4 @@ try:
 except Exception:
     print("not use mitmproxy")
 
-__version__ = "0.4.3"
+__version__ = "0.4.5"
